@@ -222,6 +222,10 @@ class TransactionWrapper(object):
     def comment(self):
         return self._trans.getComment()
 
+    @property
+    def persistence(self):
+        return self._trans.getPersistence()
+
     def tids(self):
         return [self._trans.getId()]
 
@@ -265,6 +269,10 @@ class MergedTransactionWrapper(TransactionWrapper):
     def cmdline(self):
         return self._trans.listCmdlines()
 
+    @property
+    def persistence(self):
+        return self._trans.listPersistences()
+
     @property
     def releasever(self):
         return self._trans.listReleasevers()
@@ -389,8 +397,6 @@ class SwdbInterface(object):
         rpm_item = self.rpm._pkg_to_swdb_rpm_item(pkg)
         repoid = self.repo(pkg)
         action = libdnf.transaction.TransactionItemAction_REASON_CHANGE
-        reason = reason
-        replaced_by = None
         ti = self.swdb.addItem(rpm_item, repoid, action, reason)
         ti.setState(libdnf.transaction.TransactionItemState_DONE)
         return ti
@@ -420,73 +426,13 @@ class SwdbInterface(object):
 #        return result
 
     # TODO: rename to begin_transaction?
-    def beg(self, rpmdb_version, using_pkgs, tsis, cmdline=None, comment=""):
+    def beg(self, rpmdb_version, using_pkgs, tsis, cmdline=None, comment="",
+            persistence=libdnf.transaction.TransactionPersistence_UNKNOWN):
         try:
             self.swdb.initTransaction()
         except:
             pass
 
-        '''
-        for pkg in using_pkgs:
-            pid = self.pkg2pid(pkg)
-            self.swdb.trans_with(tid, pid)
-        '''
-
-        # add RPMs to the transaction
-        # TODO: _populate_rpm_ts() ?
-
-        if self.group:
-            for group_id, group_item in sorted(self.group._installed.items()):
-                repoid = ""
-                action = libdnf.transaction.TransactionItemAction_INSTALL
-                reason = libdnf.transaction.TransactionItemReason_USER
-                replaced_by = None
-                ti = self.swdb.addItem(group_item, repoid, action, reason)
-                ti.setState(libdnf.transaction.TransactionItemState_DONE)
-
-            for group_id, group_item in sorted(self.group._upgraded.items()):
-                repoid = ""
-                action = libdnf.transaction.TransactionItemAction_UPGRADE
-                reason = libdnf.transaction.TransactionItemReason_USER
-                replaced_by = None
-                ti = self.swdb.addItem(group_item, repoid, action, reason)
-                ti.setState(libdnf.transaction.TransactionItemState_DONE)
-
-            for group_id, group_item in sorted(self.group._removed.items()):
-                repoid = ""
-                action = libdnf.transaction.TransactionItemAction_REMOVE
-                reason = libdnf.transaction.TransactionItemReason_USER
-                replaced_by = None
-                ti = self.swdb.addItem(group_item, repoid, action, reason)
-                ti.setState(libdnf.transaction.TransactionItemState_DONE)
-
-        if self.env:
-            for env_id, env_item in sorted(self.env._installed.items()):
-                repoid = ""
-                action = libdnf.transaction.TransactionItemAction_INSTALL
-                reason = libdnf.transaction.TransactionItemReason_USER
-                replaced_by = None
-                ti = self.swdb.addItem(env_item, repoid, action, reason)
-                ti.setState(libdnf.transaction.TransactionItemState_DONE)
-
-            for env_id, env_item in sorted(self.env._upgraded.items()):
-                repoid = ""
-                action = libdnf.transaction.TransactionItemAction_UPGRADE
-                reason = libdnf.transaction.TransactionItemReason_USER
-                replaced_by = None
-                ti = self.swdb.addItem(env_item, repoid, action, reason)
-                ti.setState(libdnf.transaction.TransactionItemState_DONE)
-
-            for env_id, env_item in sorted(self.env._removed.items()):
-                repoid = ""
-                action = libdnf.transaction.TransactionItemAction_REMOVE
-                reason = libdnf.transaction.TransactionItemReason_USER
-                replaced_by = None
-                ti = self.swdb.addItem(env_item, repoid, action, reason)
-                ti.setState(libdnf.transaction.TransactionItemState_DONE)
-
-
-        # save when everything is in memory
         tid = self.swdb.beginTransaction(
             int(calendar.timegm(time.gmtime())),
             str(rpmdb_version),
@@ -494,6 +440,7 @@ class SwdbInterface(object):
             int(misc.getloginuid()),
             comment)
         self.swdb.setReleasever(self.releasever)
+        self.swdb.setPersistence(persistence)
         self._tid = tid
 
         return tid
@@ -510,8 +457,6 @@ class SwdbInterface(object):
     def log_scriptlet_output(self, msg):
         if not hasattr(self, '_tid'):
             return
-        if not msg:
-            return
         for line in msg.splitlines():
             line = ucd(line)
             # logging directly to database fails if transaction runs in a background process
